@@ -24,12 +24,11 @@ To add configuration options refer to MatrixConfig.
 Server specific configuration options are handled in server.py
 """
 
+import logging
 from builtins import super
 from collections import namedtuple
 from enum import IntEnum, Enum, unique
 
-import logbook
-
 import nio
 from matrix.globals import SCRIPT_NAME, SERVERS, W
 from matrix.utf import utf8_decode
@@ -57,9 +56,8 @@ class NewChannelPosition(IntEnum):
     NEXT = 1
     NEAR_SERVER = 2
 
-
-nio.logger_group.level = logbook.ERROR
-
+nio_logger = logging.getLogger("nio")
+nio_logger.setLevel(logging.ERROR)
 
 class Option(
     namedtuple(
@@ -141,18 +139,13 @@ def change_log_level(category, level):
     Called every time the user changes the log level or log category
     configuration option."""
 
+    if category == "encryption":
+        category = "crypto"
+
     if category == "all":
-        nio.logger_group.level = level
-    elif category == "http":
-        nio.http.logger.level = level
-    elif category == "client":
-        nio.client.logger.level = level
-    elif category == "events":
-        nio.events.logger.level = level
-    elif category == "responses":
-        nio.responses.logger.level = level
-    elif category == "encryption":
-        nio.crypto.logger.level = level
+        nio_logger.setLevel(level)
+    else:
+        nio_logger.getChild(category).setLevel(level)
 
 
 @utf8_decode
@@ -178,7 +171,7 @@ def config_log_level_cb(data, option):
 @utf8_decode
 def config_log_category_cb(data, option):
     """Callback for the network.debug_category option."""
-    change_log_level(G.CONFIG.debug_category, logbook.ERROR)
+    change_log_level(G.CONFIG.debug_category, logging.ERROR)
     G.CONFIG.debug_category = G.CONFIG.network.debug_category
     change_log_level(
         G.CONFIG.network.debug_category, G.CONFIG.network.debug_level
@@ -203,20 +196,20 @@ def config_pgup_cb(data, option):
     return 1
 
 
-def level_to_logbook(value):
+def level_to_logging(value):
     if value == 0:
-        return logbook.ERROR
+        return logging.ERROR
     if value == 1:
-        return logbook.WARNING
+        return logging.WARNING
     if value == 2:
-        return logbook.INFO
+        return logging.INFO
     if value == 3:
-        return logbook.DEBUG
+        return logging.DEBUG
 
-    return logbook.ERROR
+    return logging.ERROR
 
 
-def logbook_category(value):
+def logging_category(value):
     if value == 0:
         return "all"
     if value == 1:
@@ -233,6 +226,40 @@ def logbook_category(value):
     return "all"
 
 
+def parse_nick_prefix_colors(value):
+    """Parses the nick prefix color setting string
+    ("admin=COLOR1;mod=COLOR2;power=COLOR3") into a prefix -> color dict."""
+
+    def key_to_prefix(key):
+        if key == "admin":
+            return "&"
+        elif key == "mod":
+            return "@"
+        elif key == "power":
+            return "+"
+        else:
+            return ""
+
+    prefix_colors = {
+        "&": "lightgreen",
+        "@": "lightgreen",
+        "+": "yellow",
+    }
+
+    for setting in value.split(";"):
+        # skip malformed settings
+        if "=" not in setting:
+            continue
+
+        key, color = setting.split("=")
+        prefix = key_to_prefix(key)
+
+        if prefix:
+            prefix_colors[prefix] = color
+
+    return prefix_colors
+
+
 def eval_cast(string):
     """A function that passes a string to weechat which evaluates it using its
     expression evaluation syntax.
@@ -540,6 +567,16 @@ class MatrixConfig(WeechatConfig):
                 ("Number of spaces to add as a margin around around a code "
                  "block"),
             ),
+            Option(
+                "quote_wrap",
+                "integer",
+                "",
+                -1,
+                1000,
+                "67",
+                ("After how many characters to soft-wrap lines in a quote "
+                 "block (reply message). Set to -1 to disable soft-wrapping."),
+            ),
             Option(
                 "human_buffer_names",
                 "boolean",
@@ -553,6 +590,16 @@ class MatrixConfig(WeechatConfig):
                  "since conflicts can happen otherwise "
                  "(requires a script reload)."),
             ),
+            Option(
+                "markdown_input",
+                "boolean",
+                "",
+                0,
+                0,
+                "on",
+                ("If turned on, markdown usage in messages will be converted "
+                 "to actual markup (**bold**, *italic*, _italic_, `code`)."),
+            ),
         ]
 
         network_options = [
@@ -593,7 +640,7 @@ class MatrixConfig(WeechatConfig):
                 0,
                 "error",
                 "Enable network protocol debugging.",
-                level_to_logbook,
+                level_to_logging,
                 config_log_level_cb,
             ),
             Option(
@@ -604,7 +651,7 @@ class MatrixConfig(WeechatConfig):
                 0,
                 "all",
                 "Debugging category",
-                logbook_category,
+                logging_category,
                 config_log_category_cb,
             ),
             Option(
@@ -808,6 +855,21 @@ class MatrixConfig(WeechatConfig):
                 "default",
                 "Background counterpart of untagged_code_fg",
             ),
+            Option(
+                "nick_prefixes",
+                "string",
+                "",
+                0,
+                0,
+                "admin=lightgreen;mod=lightgreen;power=yellow",
+                ('Colors for nick prefixes indicating power level. '
+                 'Format is "admin:color1;mod:color2;power:color3", '
+                 'where "admin" stands for admins (power level = 100), '
+                 '"mod" stands for moderators (power level >= 50) and '
+                 '"power" for any other power user (power level > 0). '
+                 'Requires restart to apply changes.'),
+                parse_nick_prefix_colors,
+            ),
         ]
 
         sections = [
