@@ -60,6 +60,7 @@ from nio import (
     DeleteDevicesResponse,
     TransportType,
     RoomMessagesResponse,
+    RoomMessagesError,
     EncryptionError,
     GroupEncryptionError,
     OlmTrustError,
@@ -302,11 +303,6 @@ class MatrixServer(object):
         # Enable http2 negotiation on the ssl context.
         self.ssl_context.set_alpn_protocols(["h2", "http/1.1"])
 
-        try:
-            self.ssl_context.set_npn_protocols(["h2", "http/1.1"])
-        except NotImplementedError:
-            pass
-
         self.address = None
         self.homeserver = None
         self.client = None  # type: Optional[HttpClient]
@@ -507,7 +503,7 @@ class MatrixServer(object):
             device = sas.other_olm_device
 
             if sas.verified:
-                self.info_highlight("Device {} of user {} succesfully "
+                self.info_highlight("Device {} of user {} successfully "
                                     "verified".format(
                                         device.id,
                                         device.user_id
@@ -850,9 +846,10 @@ class MatrixServer(object):
             ).format(prefix=W.prefix("network"), script_name=SCRIPT_NAME)
             W.prnt(self.server_buffer, msg)
             timeout = 0 if self.transport_type == TransportType.HTTP else 30000
+            limit = (G.CONFIG.network.max_initial_sync_events if self.first_sync else 500)
             sync_filter = {
                 "room": {
-                    "timeline": {"limit": 5000},
+                    "timeline": {"limit": limit},
                     "state": {"lazy_load_members": True}
                 }
             }
@@ -1118,6 +1115,7 @@ class MatrixServer(object):
         formatted,    # type: Formatted
         msgtype="m.text",  # type: str
         ignore_unverified_devices=False,  # type: bool
+        in_reply_to_event_id="",  # type: str
     ):
         # type: (...) -> bool
         room = room_buffer.room
@@ -1126,9 +1124,13 @@ class MatrixServer(object):
 
         content = {"msgtype": msgtype, "body": formatted.to_plain()}
 
-        if formatted.is_formatted():
+        if formatted.is_formatted() or in_reply_to_event_id:
             content["format"] = "org.matrix.custom.html"
             content["formatted_body"] = formatted.to_html()
+            if in_reply_to_event_id:
+                content["m.relates_to"] = {
+                    "m.in_reply_to": {"event_id": in_reply_to_event_id}
+                }
 
         try:
             uuid = self.room_send_event(
@@ -1156,7 +1158,7 @@ class MatrixServer(object):
         return True
 
     def print_unconfirmed_message(self, room_buffer, message):
-        """Print an outoing message before getting a recieve confirmation.
+        """Print an outgoing message before getting a receive confirmation.
 
         The message is printed out greyed out and only printed out if the
         client is configured to do so. The message needs to be later modified
@@ -1484,7 +1486,7 @@ class MatrixServer(object):
         device = sas.other_olm_device
 
         if sas.verified:
-            self.info("Device {} of user {} succesfully verified".format(
+            self.info("Device {} of user {} successfully verified".format(
                 device.id,
                 device.user_id
             ))
@@ -1612,6 +1614,9 @@ class MatrixServer(object):
 
         if isinstance(response, ErrorResponse):
             self.handle_error_response(response)
+            if isinstance(response, RoomMessagesError):
+                room_buffer = self.room_buffers[response.room_id]
+                room_buffer.backlog_pending = False
 
         elif isinstance(response, ToDeviceResponse):
             try:
@@ -1878,12 +1883,12 @@ def matrix_config_server_read_cb(
 @utf8_decode
 def matrix_config_server_write_cb(data, config_file, section_name):
     if not W.config_write_line(config_file, section_name, ""):
-        return W.WECHAT_CONFIG_WRITE_ERROR
+        return W.WEECHAT_CONFIG_WRITE_ERROR
 
     for server in SERVERS.values():
         for option in server.config._option_ptrs.values():
             if not W.config_write_option(config_file, option):
-                return W.WECHAT_CONFIG_WRITE_ERROR
+                return W.WEECHAT_CONFIG_WRITE_ERROR
 
     return W.WEECHAT_CONFIG_WRITE_OK
 
@@ -1963,7 +1968,7 @@ def matrix_timer_cb(server_name, remaining_calls):
         timeout = 0 if server.transport_type == TransportType.HTTP else 30000
         sync_filter = {
             "room": {
-                "timeline": {"limit": 5000},
+                "timeline": {"limit": 500},
                 "state": {"lazy_load_members": True}
             }
         }
